function [xx,yy]=IEPC(f,x0,y0,xn,h,err)
% function [xx,yy]=IEPC(f,x0,y0,xn,h,err)
% Implicit Euler predictor-corrector method for equation y'=f(x,y)
%        f - anonymous function
% y(x0)=y0 - initial condition
%       xn - right boundary point of the interval
%        h - step
%      err - error for accuracy of iterative method, default value 10^-6
%    xx,yy - knots and approximation solution

if nargin==5
    err=1e-6;
end
x=x0;
y=y0;
xx=x0;
yy=y0;
while x<xn

end

end % end of function EE